Welcome to ClientVPS Mirrors

Help for package clean
Title: Fast and Easy Data Cleaning
Version: 2.0.0
Date: 2020-06-01
Description: A wrapper around the new 'cleaner' package, that allows data cleaning functions for classes 'logical', 'factor', 'numeric', 'character', 'currency' and 'Date' to make data cleaning fast and easy. Relying on very few dependencies, it provides smart guessing, but with user options to override anything if needed.
Depends: R (≥ 3.0.0), cleaner (≥ 1.2.0)
URL: https://github.com/msberends/cleaner
BugReports: https://github.com/msberends/cleaner/issues
License: GPL-2
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.0
NeedsCompilation: no
Packaged: 2020-06-01 14:53:13 UTC; msberends
Author: Matthijs S. Berends ORCID iD [aut, cre]
Maintainer: Matthijs S. Berends <m.s.berends@umcg.nl>
Repository: CRAN
Date/Publication: 2020-06-01 15:10:02 UTC

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.